/* $Id: thunar-window.h 26421 2007-12-02 13:46:28Z benny $ */
/*-
 * Copyright (c) 2005-2006 Benedikt Meurer <benny@xfce.org>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __THUNAR_WINDOW_H__
#define __THUNAR_WINDOW_H__

#include <thunar/thunar-enum-types.h>
#include <thunar/thunar-folder.h>

G_BEGIN_DECLS;

typedef struct _ThunarWindowClass ThunarWindowClass;
typedef struct _ThunarWindow      ThunarWindow;

#if GLIB_CHECK_VERSION(2,14,0)
typedef GUserDirectory ThunarUserDirectory;
#define THUNAR_USER_DIRECTORY_DESKTOP      G_USER_DIRECTORY_DESKTOP
#define THUNAR_USER_DIRECTORY_DOCUMENTS    G_USER_DIRECTORY_DOCUMENTS
#define THUNAR_USER_DIRECTORY_DOWNLOAD     G_USER_DIRECTORY_DOWNLOAD
#define THUNAR_USER_DIRECTORY_MUSIC        G_USER_DIRECTORY_MUSIC
#define THUNAR_USER_DIRECTORY_PICTURES     G_USER_DIRECTORY_PICTURES
#define THUNAR_USER_DIRECTORY_PUBLIC_SHARE G_USER_DIRECTORY_PUBLIC_SHARE
#define THUNAR_USER_DIRECTORY_TEMPLATES    G_USER_DIRECTORY_TEMPLATES
#define THUNAR_USER_DIRECTORY_VIDEOS       G_USER_DIRECTORY_VIDEOS
#define THUNAR_USER_N_DIRECTORIES          G_USER_N_DIRECTORIES
#else /* GLIB_CHECK_VERSION(2,14,0) */
typedef enum
{
  THUNAR_USER_DIRECTORY_DESKTOP,
  THUNAR_USER_DIRECTORY_DOCUMENTS,
  THUNAR_USER_DIRECTORY_DOWNLOAD,
  THUNAR_USER_DIRECTORY_MUSIC,
  THUNAR_USER_DIRECTORY_PICTURES,
  THUNAR_USER_DIRECTORY_PUBLIC_SHARE,
  THUNAR_USER_DIRECTORY_TEMPLATES,
  THUNAR_USER_DIRECTORY_VIDEOS,
  THUNAR_USER_N_DIRECTORIES
} ThunarUserDirectory;
#endif /*GLIB_CHECK_VERSION(2,14,0) */

#define THUNAR_TYPE_WINDOW            (thunar_window_get_type ())
#define THUNAR_WINDOW(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), THUNAR_TYPE_WINDOW, ThunarWindow))
#define THUNAR_WINDOW_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), THUNAR_TYPE_WINDOW, ThunarWindowClass))
#define THUNAR_IS_WINDOW(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), THUNAR_TYPE_WINDOW))
#define THUNAR_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), THUNAR_TYPE_WINDOW))
#define THUNAR_WINDOW_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), THUNAR_TYPE_WINDOW, ThunarWindowClass))

GType           thunar_window_get_type              (void) G_GNUC_CONST;

GtkWidget      *thunar_window_new                   (void);

ThunarFile     *thunar_window_get_current_directory (ThunarWindow   *window);
void            thunar_window_set_current_directory (ThunarWindow   *window,
                                                     ThunarFile     *current_directory);

ThunarZoomLevel thunar_window_get_zoom_level        (ThunarWindow   *window);
void            thunar_window_set_zoom_level        (ThunarWindow   *window,
                                                     ThunarZoomLevel zoom_level);

void            thunar_window_scroll_to_file        (ThunarWindow   *window,
                                                     ThunarFile     *file,
                                                     gboolean        select,
                                                     gboolean        use_align,
                                                     gfloat          row_align,
                                                     gfloat          col_align);

G_END_DECLS;

#endif /* !__THUNAR_WINDOW_H__ */
